PCB Environment: Data Fields

PCB Environment 2

Loading...
Searching...
No Matches
Here is a list of all struct and union fields with links to the structures/unions they belong to:

### - h -

- h() : IBox_3
- halfWidth() : WideSegment_25
- has_dst : dsn::Connection
- has_dst_pin : dsn::Connection
- has_net : dsn::Pin
- has_src : dsn::Connection
- has_src_pin : dsn::Connection
- hasChanged() : PCBoard
- hasChildren() : Object
- hasEdge() : NavPoint
- hasEndCap() : Track
- hasFixedTrackParams() : PCBFactory
- hasFlags() : NavPoint
- hasListItem() : py::Object
- hasNet() : Connection, Pin
- hasParent() : Object
- hasSegmentJoints() : Track
- hasSegments() : Track
- hasStartCap() : Track
- hasTimerExpired() : Agent
- hasTracks() : Connection
- hasTupleElem() : py::Object
- hasType() : Layer
- hasValidEnds() : Track
- hasViaExtent() : Net
- hasVias() : Track
- height() : Via
- hend() : GridDirection
- hide() : IUIApplication
- HIndices() : UniformGrid25
- hprod() : IVector_2, IVector_3
- HSV() : Color
- Hues : Palette